@@ -750,7 +750,12 @@ class Analysis:
 
     def __post_init__(self):
         self.global_index = self.__prepare_global_index()
-        self.mapping = Mapping2D3D(self.structure3d, self.structure2d, False)
+        self.mapping = Mapping2D3D(
+            self.structure3d,
+            self.structure2d.basePairs,
+            self.structure2d.stackings,
+            False,
+        )
         self.tetrads = self.__find_tetrads(self.no_reorder)
         self.tetrad_scores = self.__calculate_tetrad_scores()
         self.tetrad_pairs = self.__find_tetrad_pairs(self.stacking_mismatch)
@@ -812,7 +817,7 @@ class Analysis:
         # build graph of tetrads
         while tetrads:
             graph = defaultdict(list)
-            for (ti, tj) in itertools.combinations(tetrads, 2):
+            for ti, tj in itertools.combinations(tetrads, 2):
                 if not ti.is_disjoint(tj):
                     graph[ti].append(tj)
                     graph[tj].append(ti)
@@ -1405,9 +1410,11 @@ class Visualizer:
 
 class AnalysisSimple:
     def __init__(self, structure2d: Structure2D, structure3d: Structure3D):
-        self.mapping = Mapping2D3D(structure3d, structure2d, False)
+        self.mapping = Mapping2D3D(
+            structure3d, structure2d.basePairs, structure2d.stackings, False
+        )
 
-    def has_tetrads(self):
+    def has_tetrads(self) -> bool:
         tetrads = set()
         for i in self.mapping.base_pair_graph:
             for j in self.mapping.base_pair_graph[i]:
